@@ -1,23 +1,108 @@
+#!/usr/bin/env python3
 """ Iterator Algorithms
-Collection of iterator algorithms inspired by the algorithm library of C++.
-Author: Robert Sharp
-
+IA is a collection of iterator algorithms inspired by the C++ algorithms library.
 """
 import itertools
-import operator
 import functools
-from typing import Callable, Iterator, Iterable, Any, Tuple
+import operator
+from typing import Callable, Iterator, Iterable
 
 __all__ = (
-    'accumulate', 'adjacent_difference', 'all_of', 'analytic_continuation',
-    'any_of', 'difference', 'exclusive_scan', 'flatten', 'fork', 'generate',
-    'generate_n', 'inclusive_scan', 'inner_product', 'intersection', 'iota',
-    'min_max', 'none_of', 'partial_sum', 'partition', 'product', 'reduce',
-    'symmetric_difference', 'transform', 'transform_reduce', 'transposed_sums',
-    'union', 'zip_transform',
+    'accumulate', 'adjacent_difference', 'all_of', 'any_of', 'difference',
+    'exclusive_scan', 'fork', 'generate', 'generate_n', 'inclusive_scan',
+    'inner_product', 'intersection', 'iota', 'min_max', 'none_of',
+    'partial_sum', 'partition', 'product', 'reduce', 'star_sum', 'star_product',
+    'symmetric_difference', 'transform', 'transform_reduce',
+    'transposed_sums', 'union', 'zip_transform', 'matrix_multiply',
 )
 
 
+def iota(start, *, stop=None, step=1, stride=0):
+    """ Iota
+    Iterator of a given range with grouping size equal to the stride.
+    If stride is zero - a single dimensional iterator is returned.
+
+    DocTests:
+    >>> list(iota(10))
+    [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
+    >>> list(iota(start=1, stop=11))
+    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+    >>> list(iota(start=2, stop=21, step=2))
+    [2, 4, 6, 8, 10, 12, 14, 16, 18, 20]
+    >>> list(iota(start=2, stop=21, step=2, stride=2))
+    [(2, 4), (6, 8), (10, 12), (14, 16), (18, 20)]
+
+    @param start: Beginning. Required.
+    @param stop: Ending. Default is None.
+    @param step: Stepping. Default is one.
+    @param stride: Size of groupings. Default is zero.
+    """
+    if stop is None:
+        start, stop = 0, start
+    if stride > 0:
+        groups = [iter(range(start, stop, step))] * stride
+        yield from zip(*groups)
+    else:
+        yield from iter(range(start, stop, step))
+
+
+def generate(func: Callable, *args, **kwargs):
+    """ Generate
+    Infinite iterator of a callable with arguments.
+
+    DocTests:
+    >>> counter = itertools.count(1)
+    >>> gen = generate(next, counter)
+    >>> list(next(gen) for _ in range(10))
+    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+
+    @param func: Callable.
+    @param args: Positional arguments for the functor.
+    @param kwargs: Keyword arguments for the functor.
+    """
+    while True:
+        yield func(*args, **kwargs)
+
+
+def generate_n(n: int, func: Callable, *args, **kwargs):
+    """ Generate N
+    Abstract generator function. Finite.
+
+    DocTests:
+    >>> counter = itertools.count(1)
+    >>> list(generate_n(10, next, counter))
+    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+
+    @param n: Number of elements to generate.
+    @param func: Callable.
+    @param args: Positional arguments for the functor.
+    @param kwargs: Keyword arguments for the functor.
+    """
+    for _ in range(n):
+        yield func(*args, **kwargs)
+
+
+def fork(array: Iterable, forks: int = 2) -> tuple:
+    """ Fork
+    Iterator Duplicator. Same as itertools.tee but with a better name.
+
+    DocTests:
+    >>> it = iter(range(10))
+    >>> a, b, c = fork(it, 3)
+    >>> list(c)
+    [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
+    >>> a == b
+    False
+    >>> list(a) == list(b)
+    True
+
+    @param array: Iterable to be forked.
+    @param forks: Optional Integer. Default is 2. Represents the number of forks.
+    @return: Tuple of N Iterators where N is the number of forks.
+    """
+    return itertools.tee(array, forks)
+
+
 def inclusive_scan(array: Iterable, init=None) -> Iterator:
     """ Inclusive Scan -> Adjacent Pairs
 
@@ -28,9 +113,10 @@ def inclusive_scan(array: Iterable, init=None) -> Iterator:
     [(0, 1), (1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8), (8, 9)]
 
     @param array: Iterable to be scanned.
+    @param init: Optional initial value. Default is None.
     @return: Iterator of Pairs.
     """
-    left, right = itertools.tee(array, 2)
+    left, right = fork(array)
     if init is not None:
         left = itertools.chain((init,), left)
     else:
@@ -40,23 +126,20 @@ def inclusive_scan(array: Iterable, init=None) -> Iterator:
 
 def exclusive_scan(array: Iterable, init=None) -> Iterator:
     """ Exclusive Scan -> Adjacent Pairs
-    Like inclusive_scan, but:
-        Inserts an initial value at the beginning and ignores the last value.
+    Like inclusive_scan, but ignores the last value.
 
     DocTests:
     >>> list(exclusive_scan(range(1, 10)))
     [(1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8)]
     >>> list(exclusive_scan(range(1, 10), 0))
     [(0, 1), (1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8)]
-    >>> list(exclusive_scan(range(1, 10), 10))
-    [(10, 1), (1, 2), (2, 3), (3, 4), (4, 5), (5, 6), (6, 7), (7, 8)]
 
     @param array: Iterable to be scanned.
     @param init: Initial Value.
     @return: Iterator of Pairs.
     """
-    left, right = itertools.tee(array, 2)
-    left = iter(tuple(left)[:-2])
+    left, right = fork(array)
+    right = iter(tuple(right)[:-1])
     if init is not None:
         left = itertools.chain((init, ), left)
     else:
@@ -64,26 +147,21 @@ def exclusive_scan(array: Iterable, init=None) -> Iterator:
     return zip(left, right)
 
 
-def partition(array: Iterable, predicate: Callable[[Any], bool]) -> Iterator:
-    """ Stable Partition
-    Arranges all the elements of a group such that any that return true
-        when passed to the predicate will be at the front, and the rest will be
-        at the back. The size will not change.
+def transform(array: Iterable, func: Callable) -> Iterator:
+    """ Transform
+    Similar to map but with a reversed signature.
 
     DocTests:
-    >>> list(partition(range(1, 10), is_even))
-    [2, 4, 6, 8, 1, 3, 5, 7, 9]
-    >>> list(partition(range(1, 10), is_odd))
-    [1, 3, 5, 7, 9, 2, 4, 6, 8]
+    >>> list(transform(range(10), add_one))
+    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
+    >>> list(transform(range(10), square))
+    [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
 
-    @param array: Iterable of values to be partitioned.
-    @param predicate: Unary functor. F(element) -> bool
-    @return: Partitioned Iterator.
+    @param array: Iterable of Values.
+    @param func: Unary Functor. F(x) -> Value
+    @return: Iterator of transformed Values.
     """
-    top, bottom = [], []
-    for itm in array:
-        top.append(itm) if predicate(itm) else bottom.append(itm)
-    return iter(top + bottom)
+    return map(func, array)
 
 
 def partial_sum(array: Iterable) -> Iterator:
@@ -118,66 +196,35 @@ def adjacent_difference(array: Iterable) -> Iterator:
     [-10, -8, -6, -4, -2, 0, 2, 4, 6, 8, 10]
 
     @param array: Iterable of Numeric Values.
-    @return: Iterable of adjacent differences.
-    """
-    """
-    transform -> exclusive scan, operator.sub
+    @return: Iterator of adjacent differences.
     """
     return itertools.starmap(lambda x, y: y - x, inclusive_scan(array, 0))
 
 
-def transform_reduce(lhs: Iterable, rhs: Iterable,
-                     transformer: Callable, reducer: Callable):
-    """ Transform Reduce
-    Pairwise transform and then reduction across all results.
+def partition(array: Iterable, predicate: Callable) -> Iterator:
+    """ Stable Partition
+    Arranges all the elements of a group such that any that return true
+        when passed to the predicate will be at the front, and the rest will be
+        at the back. The size of the output iterator will be the same as the
+        size of the input iterable.
 
     DocTests:
-    >>> transform_reduce(range(1, 6), range(1, 6), operator.mul, sum)
-    55
-    >>> transform_reduce(range(1, 6), range(1, 6), operator.add, product)
-    3840
+    >>> list(partition(range(1, 10), is_even))
+    [2, 4, 6, 8, 1, 3, 5, 7, 9]
+    >>> list(partition(range(1, 10), is_odd))
+    [1, 3, 5, 7, 9, 2, 4, 6, 8]
 
-    @param lhs: Left Iterator
-    @param rhs: Right Iterator
-    @param transformer: Binary Functor F(x, y) -> Value
-    @param reducer: Reduction Functor F(Iterable) -> Value
-    @return: Reduced Value
+    @param array: Iterable of values to be partitioned.
+    @param predicate: Unary functor. F(x) -> bool
+    @return: Partitioned Iterator.
     """
-    return reducer(itertools.starmap(transformer, zip(lhs, rhs)))
-
-
-def inner_product(lhs: Iterable, rhs: Iterable):
-    """ Inner Product
-    Preforms pairwise multiplication across the iterables,
-        then returns the sum of the products.
-
-    DocTests:
-    >>> inner_product(range(1, 6), range(1, 6))
-    55
-    >>> inner_product(range(11), range(11))
-    385
-
-    @param lhs: Left Iterator
-    @param rhs: Right Iterator
-    @return: Sum of the products.
-    """
-    return transform_reduce(lhs, rhs, operator.mul, sum)
-
-
-def accumulate(array: Iterable):
-    """ Accumulate
-    Sums up a range of elements. Same as reduce with operator.add
-
-    DocTests:
-    >>> accumulate(range(5))
-    10
-    >>> accumulate(range(11))
-    55
-
-    @param array: Iterable of Values to be summed.
-    @return: Sum of Values.
-    """
-    return sum(array)
+    top, bottom = [], []
+    for itm in array:
+        if predicate(itm):
+            top.append(itm)
+        else:
+            bottom.append(itm)
+    return itertools.chain(top, bottom)
 
 
 def reduce(array: Iterable, func: Callable, initial=None):
@@ -205,6 +252,23 @@ def reduce(array: Iterable, func: Callable, initial=None):
         return functools.reduce(func, array)
 
 
+def accumulate(array: Iterable):
+    """ Accumulate
+    Returns the Sum of a range of elements.
+        Same as sum() or reduce with operator.add
+
+    DocTests:
+    >>> accumulate(range(5))
+    10
+    >>> accumulate(range(11))
+    55
+
+    @param array: Iterable of Values to be summed.
+    @return: Sum of Values.
+    """
+    return sum(array)
+
+
 def product(array: Iterable):
     """ Product
     Reduce with multiply.
@@ -222,199 +286,57 @@ def product(array: Iterable):
     return reduce(array, operator.mul, initial=1)
 
 
-def transform(array: Iterable, func: Callable) -> Iterator:
-    """ Transform
-    Similar to map but with a reversed signature.
+def min_max(array: Iterable) -> tuple:
+    """ Min & Max Element
 
     DocTests:
-    >>> list(transform(range(1, 10), add_one))
-    [2, 3, 4, 5, 6, 7, 8, 9, 10]
-    >>> list(transform(range(1, 10), square))
-    [1, 4, 9, 16, 25, 36, 49, 64, 81]
+    >>> min_max(range(1, 10))
+    (1, 9)
+    >>> min_max([100, 42, 69, 1])
+    (1, 100)
 
-    @param array: Iterable of Values.
-    @param func: Unary Functor. F(x) -> Value
-    @return: Iterator of transformed Values.
+    @param array: Iterable of Numeric Values
+    @return: Tuple(Minimum, Maximum)
     """
-    return map(func, array)
+    return min(array), max(array)
 
 
-def flatten(maybe: object, *args, _flat: bool = True, **kwargs) -> object:
-    """ Flatten Maybe Callable
-    Recursively calls the maybe_callable object.
-    The first such call passes the arguments provided. F(*args, **kwargs) -> G
-    All subsequent calls are made without arguments. G()()()...
+def star_sum(*args):
+    """ Star Sum: Add All Args
+    Similar to accumulate, but takes an arbitrary number of arguments.
 
     DocTests:
-    >>> flatten(square, 8)
-    64
-    >>> flatten(is_even, 2)
-    True
-    >>> flatten(is_odd, 2)
-    False
+    >>> star_sum(1)
+    1
+    >>> star_sum(1, 2)
+    3
+    >>> star_sum(1, 2, 3)
+    6
+    >>> star_sum(1, 2, 3, 4)
+    10
 
-    @param maybe: An object that might be callable and might return a callable.
-    @param args: Optional Positional arguments for the maybe functor.
-    @param _flat: Optional Boolean. Flag to bypass flattening if set to False.
-    @param kwargs: Optional Keyword arguments for the maybe functor.
-    @return: Object returned from the final call: maybe(*args, **kwargs)()()()...
+    @param args: Numbers to be summed.
+    @return: Sum of all arguments.
     """
-    if _flat and callable(maybe):
-        try:
-            return flatten(maybe(*args, **kwargs))
-        except TypeError:
-            return maybe
-    else:
-        return maybe
+    return sum(args)
 
 
-def analytic_continuation(func: Callable, num: int, offset: int = 0) -> int:
-    """ AC: Integral Analytic Continuation
-    AC extends a function such that negative input is automatically mapped
-        to the negative number line with an offset.
+def star_product(*args):
+    """ Star Product: Multiply All Args
+    Similar to product, but takes an arbitrary number of arguments.
 
     DocTests:
-    >>> r_test = range_test(range(0, 10))
-    >>> it = [analytic_continuation(random_below, 10) for _ in range(1000)]
-    >>> all_of(it, r_test)
-    True
-    >>> r_test = range_test(range(-9, 1))
-    >>> it = [analytic_continuation(random_below, -10) for _ in range(1000)]
-    >>> all_of(it, r_test)
-    True
-    >>> r_test = range_test(range(-10, 0))
-    >>> it = [analytic_continuation(random_below, -10, -1) for _ in range(1000)]
-    >>> all_of(it, r_test)
-    True
+    >>> star_product(0, 42)
+    0
+    >>> star_product(3, 3, 3)
+    27
+    >>> star_product(1, 2, 3, 4)
+    24
 
-    @param func: Callable, should have the following signature: F(N: int) -> int
-    @param num: Integer, input for func F(N)
-    @param offset: Optional Integer, added to output of negative input -F(-N)+O
-    @return: Integer. F(N) or -F(-N)+O for negative N
-
-    Random Below Example:
-    Consider Random._randbelow as RB:
-        RB takes an int N and return a random int in range [0, N-1]
-        RB correctly raises an error if N is zero or less - unacceptable.
-        This is the canonical example of when to employ AC...
-        AC(RB, 10) -> [0, 9]             Pass-through for positive N
-        AC(RB, -10) -> [-9, 0]           Maps to the negative number line
-        AC(RB, -10, -1) -> [-10, -1]     Same as above with -1 offset
-
-    Note: when the input is zero the offset is returned - zero by default.
+    @param args: Numbers to be multiplied.
+    @return: Product of all arguments.
     """
-    if num < 0:
-        return -func(-num) + offset
-    elif num == 0:
-        return offset
-    else:
-        return func(num)
-
-
-def fork(array: Iterable, forks: int = 2) -> tuple:
-    """ Fork
-    Iterator Duplicator. Same as itertools.tee but with a better name.
-
-    DocTests:
-    >>> it = iter(range(10))
-    >>> a, b, c = fork(it, 3)
-    >>> list(c)
-    [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
-    >>> a == b
-    False
-    >>> list(a) == list(b)
-    True
-
-    @param array: Iterable to be forked.
-    @param forks: Optional Integer. Default is 2. Represents the number of forks.
-    @return: Tuple of N Iterators where N is the number of forks.
-    """
-    return itertools.tee(array, forks)
-
-
-def iota(start, stop=None, step=1, stride=1) -> Iterator:
-    """ Iota
-    Iterator of a given range with stride grouping.
-
-    DocTests:
-    >>> list(iota(11))
-    [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
-    >>> list(iota(start=1, stop=11))
-    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
-    >>> list(iota(start=2, stop=21, step=2))
-    [2, 4, 6, 8, 10, 12, 14, 16, 18, 20]
-    >>> list(iota(start=2, stop=21, step=2, stride=2))
-    [(2, 4), (6, 8), (10, 12), (14, 16), (18, 20)]
-
-    @param start: Beginning
-    @param stop: Ending
-    @param step: Stepping
-    @param stride: Number of groups.
-    @return: Iterator of a given multidimensional range.
-    """
-    if stop is None:
-        start, stop = 0, start
-    if stride > 1:
-        groups = [iter(range(start, stop, step))] * stride
-        return zip(*groups)
-    else:
-        return iter(range(start, stop, step))
-
-
-def generate(transformer: Callable, *args, **kwargs):
-    """ Generate
-    Abstract generator function. Infinite Iterator.
-
-    DocTests:
-    >>> counter = itertools.count(1)
-    >>> gen = generate(next, counter)
-    >>> list(next(gen) for _ in range(10))
-    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
-
-    @param transformer: Functor.
-    @param args: Positional arguments for the functor.
-    @param kwargs: Keyword arguments for the functor.
-    """
-    while True:
-        yield transformer(*args, **kwargs)
-
-
-def generate_n(n: int, transformer: Callable, *args, **kwargs):
-    """ Generate N
-    Abstract generator function. Finite.
-
-    DocTests:
-    >>> counter = itertools.count(1)
-    >>> list(generate_n(10, next, counter))
-    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
-
-    @param n: Maximum number of elements.
-    @param transformer: Functor.
-    @param args: Positional arguments for the functor.
-    @param kwargs: Keyword arguments for the functor.
-    """
-    for _ in range(n):
-        yield transformer(*args, **kwargs)
-
-
-def zip_transform(transformer: Callable, *args: Iterable) -> Iterator:
-    """ Zip Transform
-    The transformer should take the same number of arguments as there are iterators.
-    Each iteration will call the transformer on the ith elements.
-        F(a[i], b[i], c[i]...) ... for each i.
-
-    DocTests:
-    >>> l1 = (0, 1, 2, 3)
-    >>> l2 = (8, 7, 6, 5)
-    >>> l3 = (1, 1, 1, 1)
-    >>> list(zip_transform(add_all, l1, l2, l3))
-    [9, 9, 9, 9]
-
-    @param transformer: Functor: F(*args) -> Value
-    @param args: Any number of Iterators.
-    @return: Iterator of transformed Values.
-    """
-    return itertools.starmap(transformer, zip(*args))
+    return product(args)
 
 
 def all_of(array: Iterable, predicate: Callable) -> bool:
@@ -477,6 +399,92 @@ def none_of(array: Iterable, predicate: Callable) -> bool:
     return not any(predicate(val) for val in array)
 
 
+def transform_reduce(lhs: Iterable, rhs: Iterable,
+                     transformer: Callable, reducer: Callable):
+    """ Transform Reduce
+    Pairwise transform and then reduction across all results.
+
+    DocTests:
+    >>> transform_reduce(range(1, 6), range(1, 6), operator.mul, sum)
+    55
+    >>> transform_reduce(range(1, 6), range(1, 6), operator.add, product)
+    3840
+
+    @param lhs: Left Iterator
+    @param rhs: Right Iterator
+    @param transformer: Binary Functor F(x, y) -> Value
+    @param reducer: Reduction Functor F(Iterable) -> Value
+    @return: Reduced Value
+    """
+    return reducer(itertools.starmap(transformer, zip(lhs, rhs)))
+
+
+def inner_product(lhs: Iterable, rhs: Iterable):
+    """ Inner Product
+    Preforms pairwise multiplication across the iterables,
+        then returns the sum of the products.
+
+    DocTests:
+    >>> inner_product(range(1, 6), range(1, 6))
+    55
+    >>> inner_product(range(11), range(11))
+    385
+
+    @param lhs: Left Iterator
+    @param rhs: Right Iterator
+    @return: Sum of the products.
+    """
+    return transform_reduce(lhs, rhs, operator.mul, sum)
+
+
+def matrix_multiply(left, right):
+    """ Matrix Product
+    Row by Column inner product.
+
+    DocTests
+    >>> list(matrix_multiply([[1,2], [3,4]], [[1], [2]]))
+    [(5,), (11,)]
+    >>> list(matrix_multiply([[10,20], [30,40]], [[10], [20]]))
+    [(500,), (1100,)]
+
+    @param left: M x N matrix
+    @param right: N x P matrix
+    @return: M x P matrix
+    """
+    right = list(zip(*right))
+    return zip(
+        inner_product(row, col)
+        for row in left
+        for col in right
+    )
+
+
+def zip_transform(transducer: Callable, *args: Iterable) -> Iterator:
+    """ Zip Transform
+    The transducer should take the same number of arguments as the number of
+    iterators passed. Each iteration will call the transducer with the ith element
+    of each iterable. F(a[i], b[i], c[i]...) ...
+
+    DocTests:
+    >>> l1 = (0, 1, 2, 3)
+    >>> l2 = (8, 7, 6, 5)
+    >>> l3 = (1, 1, 1, 1)
+    >>> list(zip_transform(star_sum, []))
+    []
+    >>> list(zip_transform(star_sum, l1))
+    [0, 1, 2, 3]
+    >>> list(zip_transform(star_sum, l1, l2))
+    [8, 8, 8, 8]
+    >>> list(zip_transform(star_sum, l1, l2, l3))
+    [9, 9, 9, 9]
+
+    @param transducer: Callable
+    @param args: Any number of iterables.
+    @return: Iterator of values from the transducer.
+    """
+    return itertools.starmap(transducer, zip(*args))
+
+
 def transposed_sums(*args: Iterable) -> Iterator:
     """ Transposed Sums - Column Sums
     The size of the output iterator will be the same as
@@ -495,19 +503,6 @@ def transposed_sums(*args: Iterable) -> Iterator:
     return zip_transform(lambda *a: sum(a), *args)
 
 
-def min_max(array: Iterable) -> Tuple:
-    """ Min & Max Element
-
-    DocTests:
-    >>> min_max(range(1, 10))
-    (1, 9)
-
-    @param array: Iterable of Numeric Values
-    @return: Tuple(Minimum, Maximum)
-    """
-    return min(array), max(array)
-
-
 def union(*args: set) -> set:
     """ Multiple Set Union
     Includes all elements of every set passed in.
@@ -585,12 +580,12 @@ def symmetric_difference(*args: set) -> set:
 
 if __name__ == '__main__':
     import doctest
-    from random import randrange
 
 
     def is_even(n):
         """ Is Even
         Checks a number to see if it is even.
+            Test Helper Function
 
         DocTests:
         >>> is_even(1)
@@ -613,6 +608,7 @@ if __name__ == '__main__':
     def is_odd(n):
         """ Is Odd
         Checks a number to see if it is odd.
+            Test Helper Function
 
         DocTests:
         >>> is_odd(1)
@@ -634,6 +630,7 @@ if __name__ == '__main__':
 
     def square(n):
         """ Square of N
+            Test Helper Function
 
         DocTests:
         >>> square(1)
@@ -649,65 +646,9 @@ if __name__ == '__main__':
         return n * n
 
 
-    def add_all(*args):
-        """ Add All
-        Similar to sum, but takes an arbitrary number of arguments.
-
-        DocTests:
-        >>> add_all(1)
-        1
-        >>> add_all(1, 2)
-        3
-        >>> add_all(1, 2, 3)
-        6
-        >>> add_all(1, 2, 3, 4)
-        10
-
-        @param args: Numbers to be summed.
-        @return: Sum of all arguments.
-        """
-        return sum(args)
-
-
-    def range_test(target):
-        """ Range Test
-
-        DocTests:
-        >>> range_test(range(10))(-1)
-        False
-        >>> range_test(range(10))(0)
-        True
-        >>> range_test(range(10))(9)
-        True
-        >>> range_test(range(10))(10)
-        False
-
-        @param target: range to test
-        @return: Callable
-        """
-
-        def inner(n):
-            return n in target
-
-        return inner
-
-
-    def random_below(n):
-        """ Random Below
-
-        DocTests:
-        >>> test = range_test(range(0, 10))
-        >>> all(test(random_below(10)) for _ in range(1000))
-        True
-
-        @param n: Upper limit.
-        @return: Returns a random integer in range [0, n-1]
-        """
-        return randrange(n)
-
-
     def add_one(n):
         """ Add One
+            Test Helper Function
 
         DocTests:
         >>> add_one(41)
